@@ -1,7 +1,8 @@
 (******************************************************************************)
 (* OASIS: architecture for building OCaml libraries and applications          *)
 (*                                                                            *)
-(* Copyright (C) 2008-2010, OCamlCore SARL                                    *)
+(* Copyright (C) 2011-2013, Sylvain Le Gall                                   *)
+(* Copyright (C) 2008-2011, OCamlCore SARL                                    *)
 (*                                                                            *)
 (* This library is free software; you can redistribute it and/or modify it    *)
 (* under the terms of the GNU Lesser General Public License as published by   *)
@@ -19,32 +20,42 @@
 (* Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA              *)
 (******************************************************************************)
 
+
 (** Read-only access to 'setup.data'
-  
-    This module defines the minimal set of functions to access data 
+
+    This module defines the minimal set of functions to access data
     contained in 'setup.data'. It allows to build third party OCaml
     script, without embedding hundreeds line of code.
 
     @author Sylvain Le Gall
   *)
 
+
 module MapString: Map.S with type key = string
 
+
 type t = string MapString.t
 
-(** Environment default file 
+
+(** Environment default file
   *)
-val default_filename : string
+val default_filename: string
+
 
 (** Load environment.
   *)
-val load : ?allow_empty:bool -> ?filename:string -> unit -> t
+val load: ?allow_empty:bool -> ?filename:string -> unit -> t
+
+(** Expand a variable, replacing $(X) by variable X recursively.
+  *)
+val var_expand: string -> t -> string
 
 (** Get a variable that evaluate expression that can be found in it (see
     [Buffer.add_substitute]).
   *)
-val var_get : string -> t -> string
+val var_get: string -> t -> string
+
 
 (** Choose a value among conditional expressions.
   *)
-val var_choose : 'a OASISExpr.choices -> t -> 'a
+val var_choose: 'a OASISExpr.choices -> t -> 'a
