@@ -1,7 +1,8 @@
 (******************************************************************************)
 (* OASIS: architecture for building OCaml libraries and applications          *)
 (*                                                                            *)
-(* Copyright (C) 2008-2010, OCamlCore SARL                                    *)
+(* Copyright (C) 2011-2013, Sylvain Le Gall                                   *)
+(* Copyright (C) 2008-2011, OCamlCore SARL                                    *)
 (*                                                                            *)
 (* This library is free software; you can redistribute it and/or modify it    *)
 (* under the terms of the GNU Lesser General Public License as published by   *)
@@ -27,8 +28,8 @@ open ODN
 open OASISPlugin
 open BaseMessage
 open OASISGettext
+open OASISSetupUpdate
 
-type update = NoUpdate | Weak | Dynamic
 
 let required_modules =
   [
@@ -38,13 +39,15 @@ let required_modules =
     BaseData.basesys_ml;
   ]
 
+
 (**/**)
-let ev_create, ev_backup = 
+let ev_create, ev_backup =
   "restore_create", "restore_backup"
 
+
 let log_change f =
   function
-    | Create fn -> 
+    | Create fn ->
         f ev_create fn
 
     | Change (fn, Some bak) ->
@@ -58,41 +61,45 @@ let log_change f =
     | NoChange ->
         ()
 
+
 (**/**)
 
+
 (** Register a generated file
   *)
 let register =
   log_change BaseLog.register
 
+
 (** Unregister a generated file
   *)
 let unregister =
   log_change BaseLog.unregister
 
-let restore ?msg () = 
-  let msg = 
-    match msg with 
-      | Some e -> e 
-      | None -> !BaseContext.default 
+
+let restore ?msg () =
+  let msg =
+    match msg with
+      | Some e -> e
+      | None -> !BaseContext.default
   in
     List.iter
       (fun (ev, d) ->
-         let chng = 
+         let chng =
            if ev = ev_create then
              Create d
            else if ev = ev_backup then
-             Scanf.sscanf 
+             Scanf.sscanf
                d
                "%S -> %S"
-               (fun fn bak -> 
+               (fun fn bak ->
                   Change (fn, Some bak))
-           else 
+           else
              NoChange
          in
            file_rollback ~ctxt:msg chng;
            BaseLog.unregister ev d)
-      (BaseLog.filter 
+      (BaseLog.filter
          [ev_create; ev_backup])
 
 
@@ -105,19 +112,19 @@ let generate ?msg
       ?oasis_setup_args
       update
       pkg =
-  let ctxt, _ = 
+  let ctxt, _ =
     BaseSetup.of_package
       ?oasis_fn ?oasis_exec ?oasis_setup_args
-      ~setup_update:(update = Weak) pkg
+      ~setup_update:(update = Weak) update pkg
   in
 
-  let msg = 
-    match msg with 
-      | Some e -> e 
-      | None -> !BaseContext.default 
+  let msg =
+    match msg with
+      | Some e -> e
+      | None -> !BaseContext.default
   in
 
-  let change_setup_fn = 
+  let change_setup_fn =
     (* Do we need to change setup filename *)
     setup_fn <> BaseSetup.default_filename
   in
@@ -128,18 +135,18 @@ let generate ?msg
     in
       if change_setup_fn then
         begin
-          (* Copy the setup.ml file to its right filename 
+          (* Copy the setup.ml file to its right filename
            * and update context accordingly
            *)
           let setup_tmpl = BaseSetup.find ctxt in
 
             if Sys.file_exists default_fn then
               OASISFileUtil.cp ~ctxt:msg default_fn setup_fn;
-            {ctxt with 
-                 files = 
+            {ctxt with
+                 files =
                    OASISFileTemplate.add
                      {setup_tmpl with fn = setup_fn}
-                     (OASISFileTemplate.remove 
+                     (OASISFileTemplate.remove
                         setup_tmpl.fn
                         ctxt.files)}
         end
@@ -160,17 +167,24 @@ let generate ?msg
                    {tmpl with body =
                       Body
                         [
-                          "#use \"topfind\";;";
-                          "#require \"oasis.dynrun\";;";
-                          "open OASISDynRun;;";
+                          if OASISFeatures.package_test
+                               OASISFeatures.dynrun_for_release pkg then
+                            BaseData.dynrun_for_release_ml
+                          else if OASISFeatures.package_test
+                                    OASISFeatures.compiled_setup_ml pkg then
+                            BaseData.compiled_setup_ml
+                          else
+                            BaseData.dynrun_ml
                         ]}
                    acc
-               else if tmpl.fn = "Makefile" || tmpl.fn = "configure" then
+               else if tmpl.important then
                  OASISFileTemplate.add tmpl acc
                else
                  acc)
             ctxt.files
-            OASISFileTemplate.empty
+            (OASISFileTemplate.create
+               ~disable_oasis_section:pkg.OASISTypes.disable_oasis_section
+               ())
         in
           {ctxt with files = files}
       end
@@ -178,7 +192,7 @@ let generate ?msg
       ctxt
   in
 
-  let () = 
+  let () =
     if ctxt.error then
       failwith (s_ "There are errors during the file generation.")
   in
@@ -186,15 +200,15 @@ let generate ?msg
   let chngs =
     (* Generate files *)
     OASISFileTemplate.fold
-      (fun tmpl acc -> 
-         let chng = 
-           try 
+      (fun tmpl acc ->
+         let chng =
+           try
              file_generate ~ctxt:msg ~backup tmpl
            with e ->
              List.iter (file_rollback ~ctxt:msg) acc;
              raise e
          in
-           if restore then 
+           if restore then
              register chng;
 
            chng :: acc)
@@ -216,18 +230,18 @@ let generate ?msg
         (function
            | Change (fn, bak) as chng when setup_fn = fn ->
                begin
-                 let () = 
+                 let () =
                    unregister chng;
-                   begin 
+                   begin
                      match bak with
                        | Some fn -> Sys.remove fn
                        | None    -> ()
                    end
                  in
-                 let chng = 
+                 let chng =
                    Create fn
                  in
-                   if restore then 
+                   if restore then
                      register chng;
                    chng
                end
@@ -238,4 +252,3 @@ let generate ?msg
 
     else
         chngs
-
