@@ -1,7 +1,8 @@
 (******************************************************************************)
 (* OASIS: architecture for building OCaml libraries and applications          *)
 (*                                                                            *)
-(* Copyright (C) 2008-2010, OCamlCore SARL                                    *)
+(* Copyright (C) 2011-2013, Sylvain Le Gall                                   *)
+(* Copyright (C) 2008-2011, OCamlCore SARL                                    *)
 (*                                                                            *)
 (* This library is free software; you can redistribute it and/or modify it    *)
 (* under the terms of the GNU Lesser General Public License as published by   *)
@@ -19,23 +20,25 @@
 (* Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA              *)
 (******************************************************************************)
 
+
 (** Generate 'setup.ml' and other files
     @author Sylvain Le Gall
   *)
 
+
 open OASISTypes
 
-type update = NoUpdate | Weak | Dynamic
 
-(** Restore generated files, when [generate] has been called with 
+(** Restore generated files, when [generate] has been called with
     [~restore:true]. {b Not exported}.
   *)
-val restore : ?msg:OASISContext.t -> unit -> unit
+val restore: ?msg:OASISContext.t -> unit -> unit
+
 
 (** Generate 'setup.ml' file and the rest of the build system.
     {b Not exported}.
   *)
-val generate :
+val generate:
   ?msg:OASISContext.t ->
   restore:bool ->
   backup:bool ->
@@ -43,6 +46,6 @@ val generate :
   ?oasis_exec:host_filename ->
   ?oasis_fn:host_filename ->
   ?oasis_setup_args:string list ->
-  update ->
+  OASISSetupUpdate.t ->
   package ->
   OASISFileTemplate.file_generate_change list
