@@ -1,7 +1,8 @@
 (******************************************************************************)
 (* OASIS: architecture for building OCaml libraries and applications          *)
 (*                                                                            *)
-(* Copyright (C) 2008-2010, OCamlCore SARL                                    *)
+(* Copyright (C) 2011-2013, Sylvain Le Gall                                   *)
+(* Copyright (C) 2008-2011, OCamlCore SARL                                    *)
 (*                                                                            *)
 (* This library is free software; you can redistribute it and/or modify it    *)
 (* under the terms of the GNU Lesser General Public License as published by   *)
@@ -19,18 +20,23 @@
 (* Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA              *)
 (******************************************************************************)
 
+
 (** Entry points for 'setup.ml'
     @author Sylvain Le Gall
   *)
 
+
 open OASISTypes
 
-type std_args_fun = 
+
+type std_args_fun =
     package -> arg array -> unit
 
-type ('a, 'b) section_args_fun = 
+
+type ('a, 'b) section_args_fun =
     name * (package -> (common_section * 'a) -> arg array -> 'b)
 
+
 type t =
     {
       configure:       std_args_fun;
@@ -64,72 +70,93 @@ type t =
 
       setup_update: bool;
       (** Are we allowed to update the setup.ml (eq. of -setup-update weak). *)
-    } 
+    }
+
+
 
 (** Run the configure step.
   *)
-val configure : t -> arg array -> unit
+val configure: t -> arg array -> unit
+
 
 (** Run the build step.
   *)
-val build : t -> arg array -> unit
+val build: t -> arg array -> unit
+
 
 (** Run the doc step: build all documents.
   *)
-val doc : t -> arg array -> unit
+val doc: t -> arg array -> unit
+
 
 (** Run the test step: run all tests.
   *)
-val test : t -> arg array -> unit
+val test: t -> arg array -> unit
+
 
 (** Run the install step.
   *)
-val install : t -> arg array -> unit
+val install: t -> arg array -> unit
+
 
 (** Run the uninstall step.
   *)
-val uninstall : t -> arg array -> unit
+val uninstall: t -> arg array -> unit
+
 
 (** Run the clean step.
   *)
-val clean : t -> arg array -> unit
+val clean: t -> arg array -> unit
+
 
 (** Run the distclean step.
   *)
-val distclean : t -> arg array -> unit
+val distclean: t -> arg array -> unit
+
 
 (** Run the reinstall step: deinstall and install.
   *)
-val reinstall : t -> arg array -> unit
+val reinstall: t -> arg array -> unit
+
 
 (** Run all steps: configure, build, doc, test and install.
   *)
-val all : t -> arg array -> unit
+val all: t -> arg array -> unit
+
 
 (** Display OASIS version used to generate this setup.ml
   *)
 val version: t -> arg array -> unit
 
+
 (** The first function called when running 'setup.ml'.
   *)
-val setup : t -> unit
+val setup: t -> unit
+
+
+(** Default filename for '_oasis'.
+  *)
+val default_oasis_fn: host_filename
 
 (** Default filename for 'setup.ml'. {b Not exported}
   *)
-val default_filename : host_filename
+val default_filename: host_filename
 
-(** Get template 'setup.ml' file out of the plugin context. 
+
+(** Get template 'setup.ml' file out of the plugin context.
     {b Not exported}.
   *)
-val find : OASISPlugin.context_act -> OASISFileTemplate.template
+val find: OASISPlugin.context_act -> OASISFileTemplate.template
+
 
 (** Create [t] and plugin context from an OASIS package and the
     matching _oasis. {b Not exported}.
   *)
-val of_package :
+val of_package:
   ?oasis_fn:host_filename ->
   ?oasis_exec:host_filename ->
   ?oasis_setup_args:string list ->
   setup_update:bool ->
+  OASISSetupUpdate.t ->
   package ->
   OASISPlugin.context_act * t
