@@ -1,7 +1,8 @@
 (******************************************************************************)
 (* OASIS: architecture for building OCaml libraries and applications          *)
 (*                                                                            *)
-(* Copyright (C) 2008-2010, OCamlCore SARL                                    *)
+(* Copyright (C) 2011-2013, Sylvain Le Gall                                   *)
+(* Copyright (C) 2008-2011, OCamlCore SARL                                    *)
 (*                                                                            *)
 (* This library is free software; you can redistribute it and/or modify it    *)
 (* under the terms of the GNU Lesser General Public License as published by   *)
@@ -19,16 +20,20 @@
 (* Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA              *)
 (******************************************************************************)
 
+
 open OASISGettext
 
+
 type level =
   [ `Debug
   | `Info
   | `Warning
   | `Error]
 
+
 type t =
   {
+    (* TODO: replace this by a proplist. *)
     quiet:                 bool;
     info:                  bool;
     debug:                 bool;
@@ -37,6 +42,7 @@ type t =
     printf:                level -> string -> unit;
   }
 
+
 let printf lvl str =
   let beg =
     match lvl with
@@ -47,6 +53,7 @@ let printf lvl str =
   in
     prerr_endline (beg^str)
 
+
 let default =
   ref
     {
@@ -58,20 +65,33 @@ let default =
       printf                = printf;
     }
 
+
 let quiet =
   {!default with quiet = true}
 
 
-let args () =
+let fspecs () =
+  (* TODO: don't act on default. *)
+  let ignore_plugins = ref false in
   ["-quiet",
    Arg.Unit (fun () -> default := {!default with quiet = true}),
-   (s_ " Run quietly");
+   s_ " Run quietly";
 
    "-info",
    Arg.Unit (fun () -> default := {!default with info = true}),
-   (s_ " Display information message");
+   s_ " Display information message";
 
 
    "-debug",
    Arg.Unit (fun () -> default := {!default with debug = true}),
-   (s_ " Output debug message")]
+   s_ " Output debug message";
+
+   "-ignore-plugins",
+   Arg.Set ignore_plugins,
+   s_ " Ignore plugin's field.";
+
+   "-C",
+   (* TODO: remove this chdir. *)
+   Arg.String (fun str -> Sys.chdir str),
+   s_ "dir Change directory before running."],
+  fun () -> {!default with ignore_plugins = !ignore_plugins}
