@@ -1,7 +1,8 @@
 (******************************************************************************)
 (* OASIS: architecture for building OCaml libraries and applications          *)
 (*                                                                            *)
-(* Copyright (C) 2008-2010, OCamlCore SARL                                    *)
+(* Copyright (C) 2011-2013, Sylvain Le Gall                                   *)
+(* Copyright (C) 2008-2011, OCamlCore SARL                                    *)
 (*                                                                            *)
 (* This library is free software; you can redistribute it and/or modify it    *)
 (* under the terms of the GNU Lesser General Public License as published by   *)
@@ -19,30 +20,40 @@
 (* Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA              *)
 (******************************************************************************)
 
+
 (** i18n functions
-  
-    This module is really bind to ocaml-gettext library if gettext has been selected
-    when compiling the project. All these functions {b are exported} but their are bound
-    to {b dummy functions} in this case (i.e. not ocaml-gettext).
+
+    This module is really bind to ocaml-gettext library if gettext has been
+    selected when compiling the project. All these functions {b are exported}
+    but their are bound to {b dummy functions} in this case (i.e. not
+    ocaml-gettext).
 
     @author Sylvain Le Gall
     @see <http://forge.ocamlcore.org/projects/ocaml-gettext> OCaml Gettext project
   *)
 
+
 (** Do nothing, but register it for translation *)
 val ns_: string -> string
 
+
 (** Translate a string. *)
-val s_ : string -> string
+val s_: string -> string
+
 
 (** Translate a format string. *)
-val f_ : ('a, 'b, 'c, 'd) format4 -> ('a, 'b, 'c, 'd) format4
+val f_: ('a, 'b, 'c, 'd) format4 -> ('a, 'b, 'c, 'd) format4
+
 
 (** [fn_ fmt_singular fmt_plural n] Translate a plural string using either
     [fmt_singular] or [fmt_plural], depending of the plural status of number
     [n] in the target language.
   *)
-val fn_ : ('a, 'b, 'c, 'd) format4 -> ('a, 'b, 'c, 'd) format4 ->  int -> ('a, 'b, 'c, 'd) format4
+val fn_:
+  ('a, 'b, 'c, 'd) format4 ->
+  ('a, 'b, 'c, 'd) format4 ->
+  int -> ('a, 'b, 'c, 'd) format4
+
 
 (** Gettext initialization. *)
-val init: (string * string option * string option) list  
+val init: (string * string option * string option) list
