@@ -1,7 +1,8 @@
 (******************************************************************************)
 (* OASIS: architecture for building OCaml libraries and applications          *)
 (*                                                                            *)
-(* Copyright (C) 2008-2010, OCamlCore SARL                                    *)
+(* Copyright (C) 2011-2013, Sylvain Le Gall                                   *)
+(* Copyright (C) 2008-2011, OCamlCore SARL                                    *)
 (*                                                                            *)
 (* This library is free software; you can redistribute it and/or modify it    *)
 (* under the terms of the GNU Lesser General Public License as published by   *)
@@ -19,22 +20,28 @@
 (* Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA              *)
 (******************************************************************************)
 
+
 (** License for _oasis fields
     @author Sylvain Le Gall
   *)
 
+
 TYPE_CONV_PATH "OASISLicense"
 
+
 type license = string with odn
 
+
 type license_exception = string with odn
 
+
 type license_version =
   | Version of OASISVersion.t
   | VersionOrLater of OASISVersion.t
   | NoVersion
   with odn
 
+
 type license_dep_5_unit =
   {
     license:   license;
@@ -43,6 +50,7 @@ type license_dep_5_unit =
   }
   with odn
 
+
 type license_dep_5 =
   | DEP5Unit of license_dep_5_unit
   | DEP5Or of license_dep_5 list
@@ -54,27 +62,82 @@ type t =
   | OtherLicense of string (* URL *)
   with odn
 
+
 (* END EXPORT *)
 
+
 open OASISValues
 open OASISUtils
 open OASISGettext
 
-let string_of_license s = s
-
-let string_of_license_exception s = s
 
 type license_data =
     {
       long_name: string;
-      versions:  OASISVersion.t list;
-      note:      string option;
+      versions: OASISVersion.t list;
+      note: string option;
+      deprecated: string option;
     }
 
-let all_licenses =
-  HashStringCsl.create 13
 
-let mk_license nm ?(versions=[]) ?note long_name =
+let all_full_licenses = HashStringCsl.create 64
+let deprecated_full_licenses = ref SetStringCsl.empty
+let all_licenses = ref []
+
+
+let string_of_license s = s
+
+
+let string_of_license_exception s = s
+
+
+let string_of_license_dep_5 license_dep_5 =
+  let ver =
+    match license_dep_5.version with
+      | Version v ->
+          "-"^(OASISVersion.string_of_version v)
+      | VersionOrLater v ->
+          "-"^(OASISVersion.string_of_version v)^"+"
+      | NoVersion ->
+          ""
+  in
+  let exceptions =
+    match license_dep_5.excption with
+      | None ->
+          ""
+      | Some str ->
+          " with "^str^" exception"
+  in
+    license_dep_5.license^ver^exceptions
+
+
+let long_name_of_license_dep_5 license_dep_5 =
+  try
+    let long_name =
+      (List.assoc license_dep_5.license !all_licenses).long_name
+    in
+    let ver =
+      match license_dep_5.version with
+        | Version v ->
+            " version "^(OASISVersion.string_of_version v)
+        | VersionOrLater v ->
+            " version "^(OASISVersion.string_of_version v)^" or later"
+        | NoVersion ->
+            ""
+    in
+    let exceptions =
+      match license_dep_5.excption with
+        | None ->
+            ""
+        | Some str ->
+            " with "^str^" exception"
+    in
+      long_name^ver^exceptions
+  with Not_found ->
+    string_of_license_dep_5 license_dep_5
+
+
+let mk_license nm ?(versions=[]) ?deprecated ?note long_name =
   let rec expand_version =
     function
       | hd :: tl ->
@@ -90,24 +153,60 @@ let mk_license nm ?(versions=[]) ?note long_name =
       | [] ->
           []
   in
-  if HashStringCsl.mem all_licenses nm then
-    failwithf
-      (f_ "Duplicate license '%s'")
-      nm;
-  HashStringCsl.add all_licenses nm
+  let t =
     {
       long_name = long_name;
-      versions  = List.map
-                    OASISVersion.version_of_string
-                    (expand_version versions);
-      note      = note;
-    };
-  nm
+      versions =
+        List.map
+          OASISVersion.version_of_string
+          (expand_version versions);
+      note = note;
+      deprecated = deprecated;
+    }
+  in
+  let license_dep_5 =
+    {
+      license = nm;
+      excption = None;
+      version = NoVersion;
+    }
+  in
+  let add_full_license (full_nm, license_dep_5) =
+    if HashStringCsl.mem all_full_licenses full_nm then
+      failwithf (f_ "Duplicate license '%s'") full_nm;
+    HashStringCsl.add all_full_licenses full_nm license_dep_5
+  in
+    (* Add all expansion of license + version to the hashtable for easy
+     * retrieval.
+     *)
+    add_full_license (nm, license_dep_5);
+    List.iter
+      (fun ver ->
+         let make_nm license_dep_5 =
+           (string_of_license_dep_5 license_dep_5), license_dep_5
+         in
+           add_full_license
+             (make_nm {license_dep_5 with version = Version ver});
+           add_full_license
+             (make_nm {license_dep_5 with version = VersionOrLater ver}))
+      t.versions;
+    begin
+      match deprecated with
+        | Some str ->
+            add_full_license (str, license_dep_5);
+            deprecated_full_licenses :=
+              SetStringCsl.add str !deprecated_full_licenses
+        | None -> ()
+    end;
+    (* Append the license to all other licenses. *)
+    all_licenses := (nm, t) :: !all_licenses;
+    nm
+
 
 let license_data () =
   let lst =
-    HashStringCsl.fold
-      (fun license data acc ->
+    List.map
+      (fun (license, data) ->
          (license,
           {data with
                (* Really translate strings *)
@@ -115,40 +214,52 @@ let license_data () =
                note =
                  match data.note with
                    | Some str -> Some (s_ str)
-                   | None -> None})
-         :: acc)
-      all_licenses
-      []
+                   | None -> None}))
+      !all_licenses
   in
     List.sort (fun (nm1, _) (nm2, _) -> compare_csl nm1 nm2) lst
 
+
 let proprietary =
   mk_license
     "PROP"
     (ns_ "Proprietary license, all rights reserved")
 
+
 let apache =
   mk_license
     "Apache"
     ~versions:["1.0"; "1.1"; "2.0"]
     (ns_ "Apache license")
 
+
 let artistic =
   mk_license
     "Artistic"
     ~versions:["1.0"; "2.0"]
     (ns_ "Artistic license")
 
+
+let bsd2 =
+  mk_license
+    "BSD-2-clause"
+    (ns_ "Berkeley software distribution license (2 clauses)")
+
+
 let bsd3 =
   mk_license
-    "BSD3"
+    "BSD-3-clause"
+    ~deprecated:"BSD3"
     (ns_ "Berkeley software distribution license (3 clauses)")
 
+
 let bsd4 =
   mk_license
-    "BSD4"
+    "BSD-4-clause"
+    ~deprecated:"BSD4"
     (ns_ "Berkeley software distribution license (4 clauses)")
 
+
 let cecill =
   mk_license
     "CeCILL"
@@ -156,90 +267,107 @@ let cecill =
     ~note:(ns_ "GPL like.")
     (ns_ "CEA-CNRS-INRIA Logiciel Libre")
 
+
 let cecillb =
   mk_license
     "CeCILL-B"
     (ns_ "CEA-CNRS-INRIA Logiciel Libre, BSD-like")
 
+
 let cecillc =
   mk_license
     "CeCILL-C"
     (ns_ "CEA-CNRS-INRIA Logiciel Libre, LGPL-like")
 
+
 let freebsd =
   mk_license
     "FreeBSD"
     "FreeBSD Project license"
 
+
 let isc =
   mk_license
     "ISC"
     ~note:(ns_ "Sometimes also known as the OpenBSD License.")
     (ns_ "Internet Software Consortium's license")
 
+
 let cc_by =
   mk_license
     "CC-BY"
     (ns_ "Creative Commons Attribution license")
 
+
 let cc_by_sa =
   mk_license
     "CC-BY-SA"
     (ns_ "Creative Commons Attribution Share Alike license")
 
+
 let cc_by_nd =
   mk_license
     "CC-BY-ND"
     (ns_ "Creative Commons Attribution No Derivatives")
 
+
 let cc_by_nc =
   mk_license
     "CC-BY-NC"
     (ns_ "Creative Commons Attribution Non-Commercial")
 
+
 let cc_by_nc_sa =
   mk_license
     "CC-BY-NC-SA"
     (ns_ "Creative Commons Attribution Non-Commercial Share Alike")
 
+
 let cc_by_nc_nd =
   mk_license
     "CC-BY-NC-ND"
     (ns_ "Creative Commons Attribution Non-Commercial No Derivatives")
 
+
 let cc0 =
   mk_license
     "CC0"
     (ns_ "Creative Commons Universal waiver")
 
+
 let cddl =
   mk_license
     "CDDL"
     (ns_ "Common Development and Distribution License")
 
+
 let cpl =
   mk_license
     "CPL"
     ~versions:["1.0"]
     (ns_ "IBM Common Public License")
 
+
 let eiffel =
   mk_license
     "Eiffel"
     ~versions:["2"]
     (ns_ "The Eiffel Forum License")
 
+
 let expat =
   mk_license
     "Expat"
     (ns_ "The Expat license")
 
+
 let gpl =
   mk_license
     "GPL"
     ~versions:["1.0"; "2.0"; "3.0"]
     (ns_ "GNU General Public License")
 
+
 let lgpl =
   mk_license
     "LGPL"
@@ -247,86 +375,114 @@ let lgpl =
     ~note:"GNU Library General Public License for versions lower than 2.1"
     (ns_ "GNU Lesser General Public License")
 
+
+let agpl =
+  mk_license
+    "AGPL"
+    ~versions:["3.0"]
+    (ns_ "GNU Affero General Public License")
+
+
 let gfdl =
   mk_license
     "GFDL"
     ~versions:["1.1"; "1.2"; "1.3"]
     (ns_ "GNU Free Documentation License")
 
+
 let gfdl_niv =
   mk_license
     "GFDL-NIV"
     ~versions:["1.1"; "1.2"; "1.3"]
     (ns_ "GNU Free Documentation License, with no invariant sections")
 
+
 let lppl =
   mk_license
     "LPPL"
     ~versions:["1.3c"]
     (ns_ "LaTeX Project Public License")
 
+
 let mpl =
   mk_license
     "MPL"
     ~versions:["1.0"; "1.1"]
     (ns_ "Mozilla Public License")
 
+
 let perl =
   mk_license
     "Perl"
     ~note:(ns_ "Equates to GPL-1+ or Artistic-1.")
     (ns_ "Perl license")
 
+
 let psf =
   mk_license
     "PSF"
     ~versions:["2"]
     (ns_ "Python Software Foundation license")
 
+
 let qpl =
   mk_license
     "QPL"
     ~versions:["1.0"]
     (ns_ "Q Public License")
 
+
 let w3c_software =
   mk_license
     "W3C-Software"
     ~versions:["20021231"]
     (ns_ "W3C Software License")
 
+
 let zlib =
   mk_license
     "ZLIB"
     ~versions:["1.2.2"]
     (ns_ "zlib/libpng license")
 
+
 let zope =
   mk_license
     "Zope"
     ~versions:["1.0"; "2.0"; "2.1"]
     (ns_ "Zope Public License")
 
+
 let mit =
   mk_license
     "MIT"
     (ns_ "MIT License")
 
+
+let wtfpl =
+  mk_license
+    "WTFPL"
+    (ns_ "Do What The F*ck You Want To Public License")
+
+
 let public_domain =
   mk_license
     "PD"
     ~note:(ns_ "This is not a true license.")
     (ns_ "Public domain")
 
+
 type license_exception_data =
     {
       explanation: string;
       licenses:    license list;
     }
 
+
 let all_exceptions =
   HashStringCsl.create 13
 
+
 let mk_exception nm explanation licenses =
   if HashStringCsl.mem all_exceptions nm then
     failwithf
@@ -339,6 +495,7 @@ let mk_exception nm explanation licenses =
     };
   nm
 
+
 let license_exception_data () =
   HashStringCsl.fold
     (fun license_exception data acc ->
@@ -350,6 +507,7 @@ let license_exception_data () =
     all_exceptions
     []
 
+
 let ocaml_linking_exception =
   mk_exception
     "OCaml linking"
@@ -359,7 +517,8 @@ let ocaml_linking_exception =
           without this exception.")
     [lgpl]
 
-let parse_dep5 ~ctxt str =
+
+let parse_dep_5 ~ctxt str =
   let rec solve_token =
     function
       | OASISLicense_types.Or (t1', t2') ->
@@ -370,92 +529,17 @@ let parse_dep5 ~ctxt str =
           DEP5Unit {(decode_license lcs) with excption = decode_exception exc}
       | OASISLicense_types.License (lcs, None) ->
           DEP5Unit (decode_license lcs)
+
   and decode_license str =
-    if HashStringCsl.mem all_licenses str then
-      begin
-        {
-          license = str;
-          excption = None;
-          version = NoVersion;
-        }
-      end
-    else
-      begin
-        (* Try to find a version *)
-        let str', plus_present =
-          try
-            OASISString.strip_ends_with ~what:"+" str, true
-          with Not_found ->
-            str, false
-        in
-        let license, version =
-          let to_string lst =
-            let buf = Buffer.create (List.length lst) in
-              List.iter (Buffer.add_char buf) lst;
-              Buffer.contents buf
-          in
-          let ver = ref [] in
-          let nm = ref [] in
-          let in_ver = ref true in
-            for i = String.length str' - 1 downto 0 do
-              if !in_ver then
-                begin
-                  match str'.[i] with
-                    | '-' ->
-                        in_ver := false
-                    | '0'..'9' | '.' as c ->
-                        ver := c :: !ver
-                    | c ->
-                        nm := c :: !nm;
-                        in_ver := false
-                end
-              else
-                nm := str'.[i] :: !nm
-            done;
-            (* We don't want an empty name for license *)
-            if !nm = [] then
-              begin
-                nm := !ver;
-                ver := []
-              end;
-            if !ver = [] && plus_present then
-              begin
-                nm := !nm @ ['+']
-              end;
-            to_string !nm,
-            if !ver = [] then
-              NoVersion
-            else if plus_present then
-              VersionOrLater (OASISVersion.version_of_string (to_string !ver))
-            else
-              Version (OASISVersion.version_of_string (to_string !ver))
-        in
-          if not (HashStringCsl.mem all_licenses license) then
-            OASISMessage.warning ~ctxt
-              (f_ "Unknown license '%s' in '%s'")
-              license str
-          else
-            begin
-              match version with
-                | VersionOrLater ver | Version ver ->
-                    let license_data =
-                      HashStringCsl.find all_licenses license
-                    in
-                      if not (List.mem ver license_data.versions) then
-                        OASISMessage.warning ~ctxt
-                          (f_ "Version '%s' is not known for \
-                               license '%s' in '%s'")
-                          (OASISVersion.string_of_version ver)
-                          license str
-                | NoVersion ->
-                    ()
-            end;
-              {
-                license  = license;
-                excption = None;
-                version  = version;
-              }
-      end
+    try
+      let license_dep_5  = HashStringCsl.find all_full_licenses str in
+        if SetStringCsl.mem str !deprecated_full_licenses then
+          OASISMessage.warning ~ctxt
+            (f_ "Deprecated license %s, use %s instead.")
+            str (string_of_license_dep_5 license_dep_5);
+        license_dep_5
+    with Not_found ->
+      failwithf (f_ "Unknown license '%s'") str
 
   and decode_exception str =
       if not (HashStringCsl.mem all_exceptions str) then
@@ -503,13 +587,14 @@ let parse_dep5 ~ctxt str =
   let t' = OASISLicense_parser.main OASISLicense_lexer.token lexbuf in
     merge (solve_token t')
 
+
 let parse ~ctxt str =
     try
       OtherLicense
         (OASISValues.url.parse ~ctxt str)
     with Failure _ ->
       try
-        DEP5License (parse_dep5 ~ctxt str)
+        DEP5License (parse_dep_5 ~ctxt str)
       with e ->
         begin
           failwithf
@@ -517,56 +602,53 @@ let parse ~ctxt str =
             str (Printexc.to_string e)
         end
 
-let rec string_of_dep5 =
-  function
-    | DEP5Unit t  ->
-        begin
-          let ver =
-            match t.version with
-              | Version v ->
-                  "-"^(OASISVersion.string_of_version v)
-              | VersionOrLater v ->
-                  "-"^(OASISVersion.string_of_version v)^"+"
-              | NoVersion ->
-                  ""
-          in
-          let exceptions =
-            match t.excption with
-              | None ->
-                  ""
-              | Some str ->
-                  " with "^str^" exception"
-          in
-            t.license^ver^exceptions
-        end
 
-    | DEP5Or lst ->
-        begin
-          String.concat " or " (List.map string_of_dep5 lst)
-        end
+let rec string_of_dep_5_generic f dep_5 =
+  let rec dep_5_str =
+    function
+      | DEP5Unit t  ->
+          f t
 
-    | DEP5And [DEP5Or _ as t1; DEP5Unit _ as t2] ->
-        (string_of_dep5 t1)^", and "^(string_of_dep5 t2)
+      | DEP5Or lst ->
+          String.concat " or " (List.map dep_5_str lst)
 
-    | DEP5And lst ->
-        begin
+      | DEP5And [DEP5Or _ as t1; DEP5Unit _ as t2] ->
+          (dep_5_str t1)^", and "^(dep_5_str t2)
+
+      | DEP5And lst ->
           String.concat " and "
             (List.map
                (fun t ->
-                  let str = string_of_dep5 t in
+                  let str = dep_5_str t in
                     match t with
                       | DEP5Or _ ->
                           "("^str^")"
                       | _ ->
                           str)
                lst)
-        end
+  in
+    dep_5_str dep_5
+
 
 let to_string =
   function
-    | DEP5License dep5 -> string_of_dep5 dep5
+    | DEP5License dep_5 ->
+        string_of_dep_5_generic string_of_license_dep_5 dep_5
     | OtherLicense url -> url
 
+
+let legal_disclaimer nm =
+  function
+    | DEP5License dep_5 ->
+        Printf.sprintf
+          "%s is distributed under the terms of the %s."
+          nm (string_of_dep_5_generic long_name_of_license_dep_5 dep_5)
+    | OtherLicense url ->
+        Printf.sprintf
+          "%s is distributed using the license describe at this [URL](%s)."
+          nm url
+
+
 let value =
   {
     parse  = parse;
@@ -629,8 +711,8 @@ let choices () =
   in
 
   let all =
-    HashStringCsl.fold
-      (fun license extra acc ->
+    List.fold_left
+      (fun acc (license, data) ->
          let dflt =
            {license = license; version = NoVersion; excption = None}
          in
@@ -647,9 +729,9 @@ let choices () =
                     (exception_find license exceptions_map))
              (* only license *)
              (dflt :: acc)
-             extra.versions)
-      all_licenses
+             data.versions)
       []
+      !all_licenses
   in
 
   let all =
@@ -667,6 +749,9 @@ let choices () =
       {license = gpl;
        version =  Version (OASISVersion.version_of_string "3.0");
        excption = None};
+      {license = agpl;
+       version =  Version (OASISVersion.version_of_string "3.0");
+       excption = None};
       {license = qpl;
        version = Version (OASISVersion.version_of_string "1.0");
        excption = None};
