@@ -1,7 +1,8 @@
 (******************************************************************************)
 (* OASIS: architecture for building OCaml libraries and applications          *)
 (*                                                                            *)
-(* Copyright (C) 2008-2010, OCamlCore SARL                                    *)
+(* Copyright (C) 2011-2013, Sylvain Le Gall                                   *)
+(* Copyright (C) 2008-2011, OCamlCore SARL                                    *)
 (*                                                                            *)
 (* This library is free software; you can redistribute it and/or modify it    *)
 (* under the terms of the GNU Lesser General Public License as published by   *)
@@ -22,6 +23,7 @@
 
 TYPE_CONV_PATH "OASISTypes"
 
+
 type name          = string with odn
 type package_name  = string with odn
 type url           = string with odn
@@ -34,25 +36,30 @@ type arg           = string with odn
 type args          = string list with odn
 type command_line  = (prog * arg list) with odn
 
+
 type findlib_name = string with odn
 type findlib_full = string with odn
 
+
 type compiled_object =
   | Byte
   | Native
   | Best
   with odn
 
+
 type dependency =
   | FindlibPackage of findlib_full * OASISVersion.comparator option
   | InternalLibrary of name
   with odn
 
+
 type tool =
   | ExternalTool of name
   | InternalExecutable of name
   with odn
 
+
 type vcs =
   | Darcs
   | Git
@@ -65,6 +72,7 @@ type vcs =
   | OtherVCS of url
   with odn
 
+
 type plugin_kind =
     [  `Configure
      | `Build
@@ -74,6 +82,7 @@ type plugin_kind =
      | `Extra
     ]
 
+
 type plugin_data_purpose =
     [  `Configure
      | `Build
@@ -88,20 +97,26 @@ type plugin_data_purpose =
      | `Other of string
     ]
 
+
 type 'a plugin = 'a * name * OASISVersion.t option with odn
 
+
 type all_plugin = plugin_kind plugin
 
+
 type plugin_data = (all_plugin * plugin_data_purpose * (unit -> unit)) list
 
+
 (* END EXPORT *)
 (* TODO: really export this *)
 let odn_of_plugin_data _ =
   ODN.of_list (fun _ -> ODN.UNT) []
 (* START EXPORT *)
 
+
 type 'a conditional = 'a OASISExpr.choices with odn
 
+
 type custom =
     {
       pre_command:  (command_line option) conditional;
@@ -109,6 +124,7 @@ type custom =
     }
     with odn
 
+
 type common_section =
     {
       cs_name: name;
@@ -117,6 +133,7 @@ type common_section =
     }
     with odn
 
+
 type build_section =
     {
       bs_build:           bool conditional;
@@ -136,6 +153,7 @@ type build_section =
     }
     with odn
 
+
 type library =
     {
       lib_modules:            string list;
@@ -146,18 +164,28 @@ type library =
       lib_findlib_containers: findlib_name list;
     } with odn
 
+
+type object_ =
+    {
+      obj_modules:            string list;
+      obj_findlib_fullname:   findlib_name list option;
+    } with odn
+
+
 type executable =
     {
       exec_custom:          bool;
       exec_main_is:         unix_filename;
     } with odn
 
+
 type flag =
     {
       flag_description:  string option;
       flag_default:      bool conditional;
     } with odn
 
+
 type source_repository =
     {
       src_repo_type:        vcs;
@@ -169,6 +197,7 @@ type source_repository =
       src_repo_subdir:      unix_filename option;
     } with odn
 
+
 type test =
     {
       test_type:               [`Test] plugin;
@@ -179,6 +208,7 @@ type test =
       test_tools:              tool list;
     } with odn
 
+
 type doc_format =
   | HTML of unix_filename
   | DocText
@@ -189,6 +219,7 @@ type doc_format =
   | OtherDoc
   with odn
 
+
 type doc =
     {
       doc_type:        [`Doc] plugin;
@@ -204,8 +235,10 @@ type doc =
       doc_build_tools: tool list;
     } with odn
 
+
 type section =
   | Library    of common_section * build_section * library
+  | Object     of common_section * build_section * object_
   | Executable of common_section * build_section * executable
   | Flag       of common_section * flag
   | SrcRepo    of common_section * source_repository
@@ -213,54 +246,62 @@ type section =
   | Doc        of common_section * doc
   with odn
 
+
 type section_kind =
-    [ `Library | `Executable | `Flag | `SrcRepo | `Test | `Doc ]
+    [ `Library | `Object | `Executable | `Flag | `SrcRepo | `Test | `Doc ]
 
-type package = 
+
+type package =
     {
-      oasis_version:    OASISVersion.t;
-      ocaml_version:    OASISVersion.comparator option;
-      findlib_version:  OASISVersion.comparator option;
-      name:             package_name;
-      version:          OASISVersion.t;
-      license:          OASISLicense.t;
-      license_file:     unix_filename option;
-      copyrights:       string list;
-      maintainers:      string list;
-      authors:          string list;
-      homepage:         url option;
-      synopsis:         string;
-      description:      string option;
-      categories:       url list;
+      oasis_version:          OASISVersion.t;
+      ocaml_version:          OASISVersion.comparator option;
+      findlib_version:        OASISVersion.comparator option;
+      alpha_features:         string list;
+      beta_features:          string list;
+      name:                   package_name;
+      version:                OASISVersion.t;
+      license:                OASISLicense.t;
+      license_file:           unix_filename option;
+      copyrights:             string list;
+      maintainers:            string list;
+      authors:                string list;
+      homepage:               url option;
+      synopsis:               string;
+      description:            OASISText.t option;
+      categories:             url list;
 
-      conf_type:        [`Configure] plugin;
-      conf_custom:      custom;
+      conf_type:              [`Configure] plugin;
+      conf_custom:            custom;
 
-      build_type:       [`Build] plugin;
-      build_custom:     custom;
+      build_type:             [`Build] plugin;
+      build_custom:           custom;
 
-      install_type:     [`Install] plugin;
-      install_custom:   custom;
-      uninstall_custom: custom;
+      install_type:           [`Install] plugin;
+      install_custom:         custom;
+      uninstall_custom:       custom;
 
-      clean_custom:     custom;
-      distclean_custom: custom;
+      clean_custom:           custom;
+      distclean_custom:       custom;
 
-      files_ab:         unix_filename list;
-      sections:         section list;
-      plugins:          [`Extra] plugin list;
-      schema_data:      PropList.Data.t;
-      plugin_data:      plugin_data;
+      files_ab:               unix_filename list;
+      sections:               section list;
+      plugins:                [`Extra] plugin list;
+      disable_oasis_section:  unix_filename list;
+      schema_data:            PropList.Data.t;
+      plugin_data:            plugin_data;
     } with odn
 
+
 (* END EXPORT *)
 
+
 type 'a quickstart_level =
   | NoChoice of 'a (* Don't ask question, use provided value *)
   | Beginner
   | Intermediate
   | Expert
 
+
 type 'a quickstart_question =
   | Field
   | Text
