@@ -1,7 +1,8 @@
 (******************************************************************************)
 (* OASIS: architecture for building OCaml libraries and applications          *)
 (*                                                                            *)
-(* Copyright (C) 2008-2010, OCamlCore SARL                                    *)
+(* Copyright (C) 2011-2013, Sylvain Le Gall                                   *)
+(* Copyright (C) 2008-2011, OCamlCore SARL                                    *)
 (*                                                                            *)
 (* This library is free software; you can redistribute it and/or modify it    *)
 (* under the terms of the GNU Lesser General Public License as published by   *)
@@ -19,25 +20,28 @@
 (* Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA              *)
 (******************************************************************************)
 
+
 (** Tests for BaseVersion
     @author Sylvain Le Gall
   *)
 
-open OUnit
+
+open OUnit2
 open TestCommon
 open OASISVersion
 
+
 let tests =
 
   let vstr_compare v1 v2 =
-    version_compare 
+    version_compare
       (version_of_string v1)
       (version_of_string v2)
   in
 
   let version_compare_of_vector (v1, v2, exp) =
     (Printf.sprintf "version_compare %S %S" v1 v2) >::
-    (fun () ->
+    (fun test_ctxt ->
        let norm_sign i =
          if i = 0 then
            0
@@ -47,18 +51,18 @@ let tests =
            1
        in
          assert_equal
-           ~msg:(Printf.sprintf 
-                   "Result of '%s' and '%s' comparison" 
-                   v1 
+           ~msg:(Printf.sprintf
+                   "Result of '%s' and '%s' comparison"
+                   v1
                    v2)
            ~printer:string_of_int
-            exp
-            (norm_sign (vstr_compare v1 v2)))
+           exp
+           (norm_sign (vstr_compare v1 v2)))
   in
 
   let comparator_apply_of_vector (v, c, exp) =
     (Printf.sprintf "comparator_apply %S %S" v c) >::
-    (fun () ->
+    (fun test_ctxt ->
        let op =
          comparator_of_string c
        in
@@ -69,7 +73,7 @@ let tests =
                    v)
            ~printer:string_of_bool
            exp
-           (comparator_apply 
+           (comparator_apply
               (version_of_string v)
               op))
   in
@@ -102,22 +106,24 @@ let tests =
        ]);
 
     "sort" >::
-    (fun () ->
-       let lst = 
-         ["0.2.0~rc2"; "0.2.0~alpha1"; "0.1.0"; "0.2.0~alpha2"; "0.2.0~beta1"; "0.2.0"]
+    (fun test_ctxt ->
+       let lst =
+         ["0.2.0~rc2"; "0.2.0~alpha1"; "0.1.0"; "0.2.0~alpha2"; "0.2.0~beta1";
+          "0.2.0"]
        in
-         assert_equal 
+         assert_equal
            ~printer:(String.concat "; ")
-           ["0.1.0"; "0.2.0~alpha1"; "0.2.0~alpha2"; "0.2.0~beta1"; "0.2.0~rc2"; "0.2.0"]
+           ["0.1.0"; "0.2.0~alpha1"; "0.2.0~alpha2"; "0.2.0~beta1"; "0.2.0~rc2";
+            "0.2.0"]
            (List.sort vstr_compare lst));
 
     "back-and-forth" >::
-    (fun () ->
+    (fun test_ctxt ->
        let str = ">= 1.0 && <= 2.0 || = 3.0" in
        let cmp = comparator_of_string str in
        let cmp' = comparator_of_string (string_of_comparator cmp) in
-         assert_equal 
+         assert_equal
            ~printer:string_of_comparator
-           cmp 
+           cmp
            cmp');
   ]
